pub struct EchoLauncherGetEchoPipelinedRequest {
pub echo_prefix: String,
pub request: ServerEnd<Echo, Channel>,
}Fields
echo_prefix: Stringrequest: ServerEnd<Echo, Channel>Trait Implementations
Sourceimpl CompatFrom<EchoLauncherGetEchoPipelinedRequest> for EchoLauncherGetEchoPipelinedRequest
impl CompatFrom<EchoLauncherGetEchoPipelinedRequest> for EchoLauncherGetEchoPipelinedRequest
Sourcefn compat_from(value: EchoLauncherGetEchoPipelinedRequest) -> Self
fn compat_from(value: EchoLauncherGetEchoPipelinedRequest) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<EchoLauncherGetEchoPipelinedRequest> for EchoLauncherGetEchoPipelinedRequest
impl CompatFrom<EchoLauncherGetEchoPipelinedRequest> for EchoLauncherGetEchoPipelinedRequest
Sourcefn compat_from(value: EchoLauncherGetEchoPipelinedRequest) -> Self
fn compat_from(value: EchoLauncherGetEchoPipelinedRequest) -> Self
Converts
value into a value of this type.Sourceimpl<___E> Encode<EchoLauncherGetEchoPipelinedRequest<'static>, ___E> for EchoLauncherGetEchoPipelinedRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<EchoLauncherGetEchoPipelinedRequest<'static>, ___E> for EchoLauncherGetEchoPipelinedRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EchoLauncherGetEchoPipelinedRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EchoLauncherGetEchoPipelinedRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, EchoLauncherGetEchoPipelinedRequest<'static>>, ___E> for EchoLauncherGetEchoPipelinedRequestwhere
___E: Encoder + ?Sized,
EchoLauncherGetEchoPipelinedRequest: Encode<EchoLauncherGetEchoPipelinedRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, EchoLauncherGetEchoPipelinedRequest<'static>>, ___E> for EchoLauncherGetEchoPipelinedRequestwhere
___E: Encoder + ?Sized,
EchoLauncherGetEchoPipelinedRequest: Encode<EchoLauncherGetEchoPipelinedRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EchoLauncherGetEchoPipelinedRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EchoLauncherGetEchoPipelinedRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<EchoLauncherGetEchoPipelinedRequest<'de>> for EchoLauncherGetEchoPipelinedRequest
impl<'de> FromWire<EchoLauncherGetEchoPipelinedRequest<'de>> for EchoLauncherGetEchoPipelinedRequest
Sourcefn from_wire(wire: EchoLauncherGetEchoPipelinedRequest<'de>) -> Self
fn from_wire(wire: EchoLauncherGetEchoPipelinedRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for EchoLauncherGetEchoPipelinedRequest
impl PartialEq for EchoLauncherGetEchoPipelinedRequest
Sourcefn eq(&self, other: &EchoLauncherGetEchoPipelinedRequest) -> bool
fn eq(&self, other: &EchoLauncherGetEchoPipelinedRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EchoLauncherGetEchoPipelinedRequest