#[repr(C)]pub struct TicTacToeStartGameRequest {
pub start_first: bool,
}Fields
start_first: boolTrait Implementations
Sourceimpl Clone for TicTacToeStartGameRequest
impl Clone for TicTacToeStartGameRequest
Sourcefn clone(&self) -> TicTacToeStartGameRequest
fn clone(&self) -> TicTacToeStartGameRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
impl CompatFrom<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
Sourcefn compat_from(value: TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
fn compat_from(value: TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
Converts
value into a value of this type.Sourceimpl Debug for TicTacToeStartGameRequest
impl Debug for TicTacToeStartGameRequest
Sourceimpl<'a, ___E> Encode<TicTacToeStartGameRequest, ___E> for &'a TicTacToeStartGameRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TicTacToeStartGameRequest, ___E> for &'a TicTacToeStartGameRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeStartGameRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeStartGameRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TicTacToeStartGameRequest, ___E> for TicTacToeStartGameRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TicTacToeStartGameRequest, ___E> for TicTacToeStartGameRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TicTacToeStartGameRequest, TicTacToeStartGameRequest>
const COPY_OPTIMIZATION: CopyOptimization<TicTacToeStartGameRequest, TicTacToeStartGameRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeStartGameRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeStartGameRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TicTacToeStartGameRequest>, ___E> for &'a TicTacToeStartGameRequestwhere
___E: Encoder + ?Sized,
&'a TicTacToeStartGameRequest: Encode<TicTacToeStartGameRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TicTacToeStartGameRequest>, ___E> for &'a TicTacToeStartGameRequestwhere
___E: Encoder + ?Sized,
&'a TicTacToeStartGameRequest: Encode<TicTacToeStartGameRequest, ___E>,
Sourcefn encode_option(
this: Option<&'a TicTacToeStartGameRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TicTacToeStartGameRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TicTacToeStartGameRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TicTacToeStartGameRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TicTacToeStartGameRequest>, ___E> for TicTacToeStartGameRequest
impl<___E> EncodeOption<Box<'static, TicTacToeStartGameRequest>, ___E> for TicTacToeStartGameRequest
Sourcefn encode_option(
this: Option<TicTacToeStartGameRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TicTacToeStartGameRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TicTacToeStartGameRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TicTacToeStartGameRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
impl FromWire<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TicTacToeStartGameRequest, TicTacToeStartGameRequest>
const COPY_OPTIMIZATION: CopyOptimization<TicTacToeStartGameRequest, TicTacToeStartGameRequest>
Sourcefn from_wire(wire: TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
fn from_wire(wire: TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
impl FromWireRef<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
Sourcefn from_wire_ref(wire: &TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
fn from_wire_ref(wire: &TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
Converts the given reference to this type.
Sourceimpl Hash for TicTacToeStartGameRequest
impl Hash for TicTacToeStartGameRequest
Sourceimpl Ord for TicTacToeStartGameRequest
impl Ord for TicTacToeStartGameRequest
Sourcefn cmp(&self, other: &TicTacToeStartGameRequest) -> Ordering
fn cmp(&self, other: &TicTacToeStartGameRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for TicTacToeStartGameRequest
impl PartialOrd for TicTacToeStartGameRequest
impl Copy for TicTacToeStartGameRequest
impl Eq for TicTacToeStartGameRequest
impl StructuralPartialEq for TicTacToeStartGameRequest