#[repr(C)]pub struct EventStruct {
pub event: OptionalEvent,
}Expand description
The wire type corresponding to EventStruct.
Fields
event: OptionalEventTrait Implementations
Sourceimpl Constrained for EventStruct
impl Constrained for EventStruct
Sourceimpl Debug for EventStruct
impl Debug for EventStruct
Sourceimpl<___D> Decode<___D> for EventStructwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for EventStructwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<EventStruct, ___E> for EventStructwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<EventStruct, ___E> for EventStructwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, EventStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, EventStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EventStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EventStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<EventStruct, ___E> for EventStruct<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalEvent, ___E>,
impl<___E, T0> Encode<EventStruct, ___E> for EventStruct<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalEvent, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EventStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EventStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EventStruct> for EventStruct
impl FromWire<EventStruct> for EventStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EventStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<EventStruct, Self>
Sourcefn from_wire(wire: EventStruct) -> Self
fn from_wire(wire: EventStruct) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for EventStruct
impl IntoNatural for EventStruct
Sourcetype Natural = EventStruct
type Natural = EventStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EventStruct
impl Wire for EventStruct
Sourcetype Narrowed<'de> = EventStruct
type Narrowed<'de> = EventStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.