#[repr(C)]pub struct TicTacToeMakeMoveRequest {
pub row: u8,
pub col: u8,
}Expand description
The wire type corresponding to TicTacToeMakeMoveRequest.
Fields
row: u8col: u8Trait Implementations
Sourceimpl Clone for TicTacToeMakeMoveRequest
impl Clone for TicTacToeMakeMoveRequest
Sourcefn clone(&self) -> TicTacToeMakeMoveRequest
fn clone(&self) -> TicTacToeMakeMoveRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for TicTacToeMakeMoveRequest
impl Constrained for TicTacToeMakeMoveRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, TicTacToeMakeMoveRequest>,
_: <TicTacToeMakeMoveRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, TicTacToeMakeMoveRequest>, _: <TicTacToeMakeMoveRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for TicTacToeMakeMoveRequest
impl Debug for TicTacToeMakeMoveRequest
Sourceimpl<___D> Decode<___D> for TicTacToeMakeMoveRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for TicTacToeMakeMoveRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<TicTacToeMakeMoveRequest, ___E> for &'a TicTacToeMakeMoveRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TicTacToeMakeMoveRequest, ___E> for &'a TicTacToeMakeMoveRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeMakeMoveRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeMakeMoveRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TicTacToeMakeMoveRequest, ___E> for TicTacToeMakeMoveRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TicTacToeMakeMoveRequest, ___E> for TicTacToeMakeMoveRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TicTacToeMakeMoveRequest, TicTacToeMakeMoveRequest>
const COPY_OPTIMIZATION: CopyOptimization<TicTacToeMakeMoveRequest, TicTacToeMakeMoveRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeMakeMoveRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeMakeMoveRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<TicTacToeMakeMoveRequest, ___E> for TicTacToeMakeMoveRequest<T0, T1>
impl<___E, T0, T1> Encode<TicTacToeMakeMoveRequest, ___E> for TicTacToeMakeMoveRequest<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeMakeMoveRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeMakeMoveRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TicTacToeMakeMoveRequest> for TicTacToeMakeMoveRequest
impl FromWire<TicTacToeMakeMoveRequest> for TicTacToeMakeMoveRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TicTacToeMakeMoveRequest, TicTacToeMakeMoveRequest>
const COPY_OPTIMIZATION: CopyOptimization<TicTacToeMakeMoveRequest, TicTacToeMakeMoveRequest>
Sourcefn from_wire(wire: TicTacToeMakeMoveRequest) -> TicTacToeMakeMoveRequest
fn from_wire(wire: TicTacToeMakeMoveRequest) -> TicTacToeMakeMoveRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<TicTacToeMakeMoveRequest> for TicTacToeMakeMoveRequest
impl FromWireRef<TicTacToeMakeMoveRequest> for TicTacToeMakeMoveRequest
Sourcefn from_wire_ref(wire: &TicTacToeMakeMoveRequest) -> TicTacToeMakeMoveRequest
fn from_wire_ref(wire: &TicTacToeMakeMoveRequest) -> TicTacToeMakeMoveRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for TicTacToeMakeMoveRequest
impl IntoNatural for TicTacToeMakeMoveRequest
Sourcetype Natural = TicTacToeMakeMoveRequest
type Natural = TicTacToeMakeMoveRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TicTacToeMakeMoveRequest
impl Wire for TicTacToeMakeMoveRequest
Sourcetype Narrowed<'de> = TicTacToeMakeMoveRequest
type Narrowed<'de> = TicTacToeMakeMoveRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<TicTacToeMakeMoveRequest>)
fn zero_padding(out_: &mut MaybeUninit<TicTacToeMakeMoveRequest>)
Writes zeroes to the padding for this type, if any.