#[repr(C)]pub struct TicTacToeStartGameRequest {
pub start_first: bool,
}Expand description
The wire type corresponding to TicTacToeStartGameRequest.
Fields
start_first: boolTrait Implementations
Sourceimpl Clone for TicTacToeStartGameRequest
impl Clone for TicTacToeStartGameRequest
Sourcefn clone(&self) -> TicTacToeStartGameRequest
fn clone(&self) -> TicTacToeStartGameRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for TicTacToeStartGameRequest
impl Constrained for TicTacToeStartGameRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, TicTacToeStartGameRequest>,
_: <TicTacToeStartGameRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, TicTacToeStartGameRequest>, _: <TicTacToeStartGameRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for TicTacToeStartGameRequest
impl Debug for TicTacToeStartGameRequest
Sourceimpl<___D> Decode<___D> for TicTacToeStartGameRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for TicTacToeStartGameRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<TicTacToeStartGameRequest, ___E> for &'a TicTacToeStartGameRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TicTacToeStartGameRequest, ___E> for &'a TicTacToeStartGameRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeStartGameRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeStartGameRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TicTacToeStartGameRequest, ___E> for TicTacToeStartGameRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TicTacToeStartGameRequest, ___E> for TicTacToeStartGameRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TicTacToeStartGameRequest, TicTacToeStartGameRequest>
const COPY_OPTIMIZATION: CopyOptimization<TicTacToeStartGameRequest, TicTacToeStartGameRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeStartGameRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeStartGameRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<TicTacToeStartGameRequest, ___E> for TicTacToeStartGameRequest<T0>
impl<___E, T0> Encode<TicTacToeStartGameRequest, ___E> for TicTacToeStartGameRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeStartGameRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeStartGameRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
impl FromWire<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TicTacToeStartGameRequest, TicTacToeStartGameRequest>
const COPY_OPTIMIZATION: CopyOptimization<TicTacToeStartGameRequest, TicTacToeStartGameRequest>
Sourcefn from_wire(wire: TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
fn from_wire(wire: TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
impl FromWireRef<TicTacToeStartGameRequest> for TicTacToeStartGameRequest
Sourcefn from_wire_ref(wire: &TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
fn from_wire_ref(wire: &TicTacToeStartGameRequest) -> TicTacToeStartGameRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for TicTacToeStartGameRequest
impl IntoNatural for TicTacToeStartGameRequest
Sourcetype Natural = TicTacToeStartGameRequest
type Natural = TicTacToeStartGameRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TicTacToeStartGameRequest
impl Wire for TicTacToeStartGameRequest
Sourcetype Narrowed<'de> = TicTacToeStartGameRequest
type Narrowed<'de> = TicTacToeStartGameRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<TicTacToeStartGameRequest>)
fn zero_padding(out_: &mut MaybeUninit<TicTacToeStartGameRequest>)
Writes zeroes to the padding for this type, if any.